@@ -1,7 +1,7 @@
 // qjackctl.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -82,13 +82,16 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 
 #ifdef CONFIG_XUNIQUE
 
-#define QJACKCTL_XUNIQUE "qjackctlApplication"
-
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 #ifdef CONFIG_X11
+
+#define QJACKCTL_XUNIQUE "qjackctlApplication"
+
 #include <unistd.h> /* for gethostname() */
+
 #include <X11/Xatom.h>
 #include <X11/Xlib.h>
+
 #endif	// CONFIG_X11
 #else
 #include <QSharedMemory>
@@ -107,6 +110,18 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 qjackctlApplication::qjackctlApplication ( int& argc, char **argv )
 	: QApplication(argc, argv),
 		m_pQtTranslator(nullptr), m_pMyTranslator(nullptr), m_pWidget(nullptr)
+#ifdef CONFIG_XUNIQUE
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+#ifdef CONFIG_X11
+	, m_pDisplay(nullptr)
+	, m_aUnique(0)
+	, m_wOwner(0)
+#endif	// CONFIG_X11
+#else
+	, m_pMemory(nullptr)
+	, m_pServer(nullptr)
+#endif
+#endif	// CONFIG_XUNIQUE
 {
 #if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
 	QApplication::setApplicationName(QJACKCTL_TITLE);
@@ -114,9 +129,9 @@ qjackctlApplication::qjackctlApplication ( int& argc, char **argv )
 	//	QJACKCTL_TITLE " - " + QObject::tr(QJACKCTL_SUBTITLE));
 #if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
 	QApplication::setDesktopFileName(
-		QString("org.rncbc.%1").arg(PACKAGE_TARNAME));
+		QString("org.rncbc.%1").arg(PROJECT_NAME));
 #endif
-	QString sVersion(CONFIG_BUILD_VERSION);
+	QString sVersion(PROJECT_VERSION);
 	sVersion += '\n';
 	sVersion += QString("Qt: %1").arg(qVersion());
 #if defined(QT_STATIC)
@@ -178,18 +193,6 @@ qjackctlApplication::qjackctlApplication ( int& argc, char **argv )
 			}
 		}
 	}
-#ifdef CONFIG_XUNIQUE
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-#ifdef CONFIG_X11
-	m_pDisplay = nullptr;
-	m_aUnique = 0;
-	m_wOwner = 0;
-#endif	// CONFIG_X11
-#else
-	m_pMemory = nullptr;
-	m_pServer = nullptr;
-#endif
-#endif	// CONFIG_XUNIQUE
 }
 
 
@@ -198,15 +201,7 @@ qjackctlApplication::~qjackctlApplication (void)
 {
 #ifdef CONFIG_XUNIQUE
 #if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
-	if (m_pServer) {
-		m_pServer->close();
-		delete m_pServer;
-		m_pServer = nullptr;
-	}
-	if (m_pMemory) {
-		delete m_pMemory;
-		m_pMemory = nullptr;
-	}
+	clearServer();
 #endif
 #endif	// CONFIG_XUNIQUE
 	if (m_pMyTranslator) delete m_pMyTranslator;
@@ -238,6 +233,7 @@ void qjackctlApplication::setMainWidget ( QWidget *pWidget )
 bool qjackctlApplication::setup ( const QString& sServerName )
 {
 #ifdef CONFIG_XUNIQUE
+	m_sServerName = sServerName;
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 #ifdef CONFIG_X11
 	m_pDisplay = QX11Info::display();
@@ -309,72 +305,7 @@ bool qjackctlApplication::setup ( const QString& sServerName )
 #endif	// CONFIG_X11
 	return false;
 #else
-	m_sUnique = QCoreApplication::applicationName();
-	if (!sServerName.isEmpty()) {
-		m_sUnique += '-';
-		m_sUnique += sServerName;
-	}
-	QString sUserName = QString::fromUtf8(::getenv("USER"));
-	if (sUserName.isEmpty())
-		sUserName = QString::fromUtf8(::getenv("USERNAME"));
-	if (!sUserName.isEmpty()) {
-		m_sUnique += ':';
-		m_sUnique += sUserName;
-	}
-	m_sUnique += '@';
-	m_sUnique += QHostInfo::localHostName();
-#if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
-	const QNativeIpcKey nativeKey
-		= QSharedMemory::legacyNativeKey(m_sUnique);
-	m_pMemory = new QSharedMemory(nativeKey);
-#else
-#if defined(Q_OS_UNIX)
-	m_pMemory = new QSharedMemory(m_sUnique);
-	m_pMemory->attach();
-	delete m_pMemory;
-#endif
-	m_pMemory = new QSharedMemory(m_sUnique);
-#endif
-	bool bServer = false;
-	const qint64 pid = QCoreApplication::applicationPid();
-	struct Data { qint64 pid; };
-	if (m_pMemory->create(sizeof(Data))) {
-		m_pMemory->lock();
-		Data *pData = static_cast<Data *> (m_pMemory->data());
-		if (pData) {
-			pData->pid = pid;
-			bServer = true;
-		}
-		m_pMemory->unlock();
-	}
-	else
-	if (m_pMemory->attach()) {
-		m_pMemory->lock(); // maybe not necessary?
-		Data *pData = static_cast<Data *> (m_pMemory->data());
-		if (pData)
-			bServer = (pData->pid == pid);
-		m_pMemory->unlock();
-	}
-	if (bServer) {
-		QLocalServer::removeServer(m_sUnique);
-		m_pServer = new QLocalServer();
-		m_pServer->setSocketOptions(QLocalServer::UserAccessOption);
-		m_pServer->listen(m_sUnique);
-		QObject::connect(m_pServer,
-			SIGNAL(newConnection()),
-			SLOT(newConnectionSlot()));
-	} else {
-		QLocalSocket socket;
-		socket.connectToServer(m_sUnique);
-		if (socket.state() == QLocalSocket::ConnectingState)
-			socket.waitForConnected(200);
-		if (socket.state() == QLocalSocket::ConnectedState) {
-			socket.write(QCoreApplication::arguments().join(' ').toUtf8());
-			socket.flush();
-			socket.waitForBytesWritten(200);
-		}
-	}
-	return !bServer;
+	return setupServer();
 #endif
 #else
 	return false;
@@ -437,6 +368,106 @@ bool qjackctlApplication::x11EventFilter ( XEvent *pEv )
 #endif	// CONFIG_X11
 #else
 
+// Local server/shmem setup.
+bool qjackctlApplication::setupServer (void)
+{
+	clearServer();
+
+	m_sUnique = QCoreApplication::applicationName();
+	if (!m_sServerName.isEmpty()) {
+		m_sUnique += '-';
+		m_sUnique += m_sServerName;
+	}
+	QString sUserName = QString::fromUtf8(::getenv("USER"));
+	if (sUserName.isEmpty())
+		sUserName = QString::fromUtf8(::getenv("USERNAME"));
+	if (!sUserName.isEmpty()) {
+		m_sUnique += ':';
+		m_sUnique += sUserName;
+	}
+	m_sUnique += '@';
+	m_sUnique += QHostInfo::localHostName();
+#if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
+	const QNativeIpcKey nativeKey
+		= QSharedMemory::legacyNativeKey(m_sUnique);
+#if defined(Q_OS_UNIX)
+	m_pMemory = new QSharedMemory(nativeKey);
+	m_pMemory->attach();
+	delete m_pMemory;
+#endif
+	m_pMemory = new QSharedMemory(nativeKey);
+#else
+#if defined(Q_OS_UNIX)
+	m_pMemory = new QSharedMemory(m_sUnique);
+	m_pMemory->attach();
+	delete m_pMemory;
+#endif
+	m_pMemory = new QSharedMemory(m_sUnique);
+#endif
+
+	bool bServer = false;
+	const qint64 pid = QCoreApplication::applicationPid();
+	struct Data { qint64 pid; };
+	if (m_pMemory->create(sizeof(Data))) {
+		m_pMemory->lock();
+		Data *pData = static_cast<Data *> (m_pMemory->data());
+		if (pData) {
+			pData->pid = pid;
+			bServer = true;
+		}
+		m_pMemory->unlock();
+	}
+	else
+	if (m_pMemory->attach()) {
+		m_pMemory->lock(); // maybe not necessary?
+		Data *pData = static_cast<Data *> (m_pMemory->data());
+		if (pData)
+			bServer = (pData->pid == pid);
+		m_pMemory->unlock();
+	}
+
+	if (bServer) {
+		QLocalServer::removeServer(m_sUnique);
+		m_pServer = new QLocalServer();
+		m_pServer->setSocketOptions(QLocalServer::UserAccessOption);
+		m_pServer->listen(m_sUnique);
+		QObject::connect(m_pServer,
+			SIGNAL(newConnection()),
+			SLOT(newConnectionSlot()));
+	} else {
+		QLocalSocket socket;
+		socket.connectToServer(m_sUnique);
+		if (socket.state() == QLocalSocket::ConnectingState)
+			socket.waitForConnected(200);
+		if (socket.state() == QLocalSocket::ConnectedState) {
+			socket.write(QCoreApplication::arguments().join(' ').toUtf8());
+			socket.flush();
+			socket.waitForBytesWritten(200);
+		}
+	}
+
+	return !bServer;
+}
+
+
+// Local server/shmem cleanup.
+void qjackctlApplication::clearServer (void)
+{
+	if (m_pServer) {
+		m_pServer->close();
+		delete m_pServer;
+		m_pServer = nullptr;
+	}
+
+	if (m_pMemory) {
+		delete m_pMemory;
+		m_pMemory = nullptr;
+	}
+
+	m_sUnique.clear();
+}
+
+
 // Local server conection slot.
 void qjackctlApplication::newConnectionSlot (void)
 {
@@ -495,6 +526,8 @@ void qjackctlApplication::readyReadSlot (void)
 					}
 				}
 			}
+			// Reset the server...
+			setupServer();
 		}
 	}
 }
@@ -595,13 +628,13 @@ int main ( int argc, char **argv )
 	}
 
 	// Check if we'll just start an external program...
-	if (!setup.sCmdLine.isEmpty()) {
+	if (!setup.cmdLine.isEmpty()) {
 		jack_client_t *pJackClient
 			= jack_client_open("qjackctl-start", JackNoStartServer, nullptr);
 		if (pJackClient) {
 			jack_client_close(pJackClient);
 			const int iExitStatus
-				= ::system(setup.sCmdLine.toUtf8().constData());
+				= ::system(setup.cmdLine.join(' ').toUtf8().constData());
 			app.quit();
 			return iExitStatus;
 		}
