@@ -1,7 +1,7 @@
 // qjackctlConnectionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -19,11 +19,8 @@
 
 *****************************************************************************/
 
-#include "qjackctlAbout.h"
 #include "qjackctlConnectionsForm.h"
 
-#include "qjackctlSetup.h"
-
 #include "qjackctlMainForm.h"
 #include "qjackctlPatchbay.h"
 
