@@ -1,7 +1,7 @@
-// qjackctlGraph.cpp
+// qjackctlGraphCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -125,17 +125,26 @@ bool qjackctlGraphConnectCommand::execute ( bool is_undo )
 // Constructor.
 qjackctlGraphMoveCommand::qjackctlGraphMoveCommand ( qjackctlGraphCanvas *canvas,
 	const QList<qjackctlGraphNode *>& nodes, const QPointF& pos1, const QPointF& pos2,
-	qjackctlGraphCommand *parent ) : qjackctlGraphCommand(canvas, parent),
-		m_pos1(pos1), m_pos2(pos2), m_nexec(0)
+	qjackctlGraphCommand *parent ) : qjackctlGraphCommand(canvas, parent), m_nexec(0)
 {
 	qjackctlGraphCommand::setText(QObject::tr("Move"));
 
+	const QPointF delta = (pos1 - pos2);
+
 	foreach (qjackctlGraphNode *node, nodes) {
 		Item *item = new Item;
 		item->node_name = node->nodeName();
 		item->node_mode = node->nodeMode();
 		item->node_type = node->nodeType();
-		m_items.append(item);
+		const QPointF& pos = node->pos();
+		item->node_pos1 = pos + delta;
+		item->node_pos2 = pos;
+		m_items.insert(node, item);
+	}
+
+	if (canvas && canvas->isRepelOverlappingNodes()) {
+		foreach (qjackctlGraphNode *node, nodes)
+			canvas->repelOverlappingNodes(node, this);
 	}
 }
 
@@ -148,6 +157,27 @@ qjackctlGraphMoveCommand::~qjackctlGraphMoveCommand (void)
 }
 
 
+// Add/replace (an already moved) node position for undo/redo...
+void qjackctlGraphMoveCommand::addItem (
+	qjackctlGraphNode *node, const QPointF& pos1, const QPointF& pos2 )
+{
+	Item *item = m_items.value(node, nullptr);
+	if (item) {
+	//	item->node_pos1 = pos1;
+		item->node_pos2 = pos2;//node->pos();
+	} else {
+		item = new Item;
+		item->node_name = node->nodeName();
+		item->node_mode = node->nodeMode();
+		item->node_type = node->nodeType();
+		item->node_pos1 = pos1;
+		item->node_pos2 = pos2;//node->pos();
+		m_items.insert(node, item);
+	}
+}
+
+
+
 // Command executive method.
 bool qjackctlGraphMoveCommand::execute ( bool /* is_undo */ )
 {
@@ -156,19 +186,21 @@ bool qjackctlGraphMoveCommand::execute ( bool /* is_undo */ )
 		return false;
 
 	if (++m_nexec > 1) {
-		const QPointF delta = (m_pos2 - m_pos1);
-		foreach (Item *item, m_items) {
-			qjackctlGraphNode *node = canvas->findNode(
-				item->node_name, item->node_mode, item->node_type);
-			if (node)
-				node->setPos(node->pos() + delta);
+		foreach (qjackctlGraphNode *key, m_items.keys()) {
+			Item *item = m_items.value(key, nullptr);
+			if (item) {
+				qjackctlGraphNode *node = canvas->findNode(
+					item->node_name, item->node_mode, item->node_type);
+				if (node) {
+					const QPointF pos1 = item->node_pos1;
+					node->setPos(pos1);
+					item->node_pos1 = item->node_pos2;
+					item->node_pos2 = pos1;
+				}
+			}
 		}
 	}
 
-	QPointF pos2 = m_pos2;
-	m_pos2 = m_pos1;
-	m_pos1 = pos2;
-
 	return true;
 }
 
