@@ -1,7 +1,7 @@
 // qjackctlJackConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -145,9 +145,9 @@ void qjackctlJackPort::updatePortName ( bool bRename )
 				removePrettyName(pJackClient, port_uuid);
 			}
 			setPortText(sPortNameEx, bRenameEnabled);
-			return;
 		}
 	}
+	else
 #endif
 	qjackctlPortItem::updatePortName(bRename);
 }
@@ -337,12 +337,14 @@ int qjackctlJackClientList::updateClientPorts (void)
 		pszJackType = JACK_DEFAULT_MIDI_TYPE;
 #endif
 
+#ifdef CONFIG_JACK_PORT_ALIASES
 	char *aliases[2];
 	if (g_iJackClientPortAlias > 0) {
 		const unsigned short alias_size = jack_port_name_size() + 1;
 		aliases[0] = new char [alias_size];
 		aliases[1] = new char [alias_size];
 	}
+#endif
 
 	int iDirtyCount = 0;
 
@@ -369,15 +371,15 @@ int qjackctlJackClientList::updateClientPorts (void)
 				pClient = static_cast<qjackctlJackClient *> (findClient(sClientName));
 				if (pClient)
 					pPort = static_cast<qjackctlJackPort *> (pClient->findPort(sPortName));
-				if (pClient == 0) {
+				if (pClient == nullptr) {
 					pClient = new qjackctlJackClient(this);
 					pClient->setClientName(sClientName);
-					iDirtyCount++;
+					++iDirtyCount;
 				}
-				if (pClient && pPort == 0) {
+				if (pClient && pPort == nullptr) {
 					pPort = new qjackctlJackPort(pClient, jack_port_flags(pJackPort));
 					pPort->setPortName(sPortName);
-					iDirtyCount++;
+					++iDirtyCount;
 				}
 				if (pPort)
 					pPort->markClientPort(1);
@@ -388,10 +390,12 @@ int qjackctlJackClientList::updateClientPorts (void)
 
 	iDirtyCount += cleanClientPorts(0);
 
+#ifdef CONFIG_JACK_PORT_ALIASES
 	if (g_iJackClientPortAlias > 0) {
 		delete [] aliases[0];
 		delete [] aliases[1];
 	}
+#endif
 
 	return iDirtyCount;
 }
@@ -569,6 +573,9 @@ void qjackctlJackConnect::updateConnections (void)
 	if (pIClientList == nullptr)
 		return;
 
+#ifdef CONFIG_JACK_PORT_ALIASES
+	const int iJackClientPortAlias = qjackctlJackClientList::jackClientPortAlias();
+#endif
 	// For each output client item...
 	QListIterator<qjackctlClientItem *> oclient(OClientList()->clients());
 	while (oclient.hasNext()) {
@@ -597,9 +604,31 @@ void qjackctlJackConnect::updateConnections (void)
 					// Now, for each input client port...
 					for (int iClientPort = 0;
 							ppszClientPorts[iClientPort]; ++iClientPort) {
-						qjackctlPortItem *pIPort
-							= pIClientList->findJackClientPort(
+						qjackctlPortItem *pIPort = nullptr;
+					#ifdef CONFIG_JACK_PORT_ALIASES
+						if (iJackClientPortAlias > 0) {
+							// If Jack aliases are in effect, look for those if present -ag
+							jack_port_t *pIJackPort
+								= jack_port_by_name(pJackClient, ppszClientPorts[iClientPort]);
+							if (pIJackPort) {
+								char *aliases[2];
+								const unsigned short alias_size = jack_port_name_size() + 1;
+								aliases[0] = new char [alias_size];
+								aliases[1] = new char [alias_size];
+								if (jack_port_get_aliases(pIJackPort, aliases) >= iJackClientPortAlias) {
+									pIPort = pIClientList->findJackClientPort(aliases[iJackClientPortAlias - 1]);
+								}
+								delete [] aliases[0];
+								delete [] aliases[1];
+							}
+							// Otherwise we fall through to the default case below
+							// which looks for the port under its real name
+						}
+					#endif
+						if (!pIPort) {
+							pIPort = pIClientList->findJackClientPort(
 								ppszClientPorts[iClientPort]);
+						}
 						if (pIPort) {
 							pOPort->addConnect(pIPort);
 							pIPort->addConnect(pOPort);
