@@ -1,7 +1,7 @@
 // qjackctlSetup.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -129,7 +129,7 @@ public:
 	bool bStopJack;
 
 	// User supplied command line.
-	QString sCmdLine;
+	QStringList cmdLine;
 
 	// Current/previous (default) preset name.
 	QString sDefPreset;
